@@ -133,6 +133,12 @@
 #define PRESET_BIG_FONT_COLOR_BACK "#000000"
 #define PRESET_WIND_FONT_COLOR "#000000"
 #define PRESET_FONT_COLOR_LOW_TEMP "#7D9CAD"
+#define OMWEATHER_SIGNAL_INTERFACE "org.maemo.omweather"
+#define OMWEATHER_SIGNAL_PATH "/org/maemo/omweather"
+#define OMWEATHER_SIGNAL_RELOAD_CONFIG_INTERFACE "org.maemo.omweather.reload_config"
+#define OMWEATHER_SIGNAL_RELOAD_CONFIG_PATH "/org/maemo/omweather/reload_config"
+#define OMWEATHER_RELOAD_CONFIG "reload_config"
+#define OMWEATHER_RELOAD_PLUGIN "reload_plugin"
 
 /*******************************************************************************/
 enum { AUTOUPDATE, CHANGE_DAY_PART, DBUSINITEVENT, UPDATE_AFTER_CONNECTED,
@@ -520,6 +526,7 @@ typedef struct OMWeatherApplet{
 #endif
 #ifdef USE_DBUS
     DBusConnection      *dbus_conn;
+    DBusConnection      *dbus_conn_session;
 #endif
 #ifdef CLUTTER
     ClutterScript       *clutter_script; /* Maybe it need be deleting */
@@ -592,13 +599,13 @@ G_END_DECLS
 
 G_BEGIN_DECLS
 
-#define OMWEATHER_TYPE_DESKTOP_WIDGET omweather_desktop_widget_get_type()
+#define OMWEATHER_TYPE_DESKTOP_WIDGET omweather_plugin_get_type()
 
 #define OMWEATHER_DESKTOP_WIDGET(obj) \
     (G_TYPE_CHECK_INSTANCE_CAST ((obj), OMWEATHER_TYPE_DESKTOP_WIDGET, OmweatherPlugin))
 
 #define OMWEATHER_DESKTOP_WIDGET_CLASS(klass) \
-    (G_TYPE_CHECK_CLASS_CAST ((klass), OMWEATHER_TYPE_DESKTOP_WIDGET, OmweatherDesktopWidgetClass))
+    (G_TYPE_CHECK_CLASS_CAST ((klass), OMWEATHER_TYPE_DESKTOP_WIDGET, OmweatherPlugintClass))
 
 #define OMWEATHER_IS_DESKTOP_WIDGET(obj) \
     (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OMWEATHER_TYPE_DESKTOP_WIDGET))
@@ -607,21 +614,21 @@ G_BEGIN_DECLS
     (G_TYPE_CHECK_CLASS_TYPE ((klass), OMWEATHER_TYPE_DESKTOP_WIDGET))
 
 #define OMWEATHER_DESKTOP_WIDGET_GET_CLASS(obj) \
-          (G_TYPE_INSTANCE_GET_CLASS ((obj), OMWEATHER_TYPE_DESKTOP_WIDGET, OmweatherDesktopWidgetClass))
+          (G_TYPE_INSTANCE_GET_CLASS ((obj), OMWEATHER_TYPE_DESKTOP_WIDGET, OmweatherPluginClass))
 
 
 
 typedef struct {
   HDHomePluginItem       parent;
-} OmweatherDesktopWidget;
+} OmweatherPlugin;
 
 
 typedef struct {
   HDHomePluginItemClass  parent_class;
-} OmweatherDesktopWidgetClass;
+} OmweatherPluginClass;
 
 GType omweather_plugin_get_type (void);
-OmweatherDesktopWidget* omweather_plugin_widget_new (void);
+//OmweatherPlugin* omweather_plugin_widget_new (void);
 
 
 G_END_DECLS
