@@ -45,15 +45,11 @@
 #endif
 /*******************************************************************************/
 void
-weather_initialize_dbus(void){
+weather_initialize_dbus(gpointer applet){
     gchar   *tmp;
-#if defined USE_DBUS && !defined OS2008 && !defined OS2009 
     gchar       *filter_string;
     DBusError   error;
-#endif
-#if defined USE_DBUS && !defined OS2008
-    DBusError error;
-#endif
+
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -78,8 +74,15 @@ weather_initialize_dbus(void){
 #endif
 
 #ifdef USE_DBUS
+        dbus_error_init (&error);
         /* Add D-BUS signal handler for 'status_changed' */
+#if defined OS2009 && !defined APPLICATION
+        app->dbus_conn = (DBusConnection *) osso_get_sys_dbus_connection(app->osso);
+        app->dbus_conn_session = (DBusConnection *) osso_get_dbus_connection(app->osso);
+#else
         app->dbus_conn = dbus_bus_get(DBUS_BUS_SYSTEM, NULL);
+        app->dbus_conn_session = dbus_bus_get(DBUS_BUS_SESSION, NULL);
+#endif
 
 #if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
         filter_string =
@@ -100,7 +103,20 @@ weather_initialize_dbus(void){
 #endif
 
         check_current_connection();
-
+        if (app->dbus_conn_session){
+            filter_string =
+                g_strdup_printf("type='signal', interface='%s'", OMWEATHER_SIGNAL_INTERFACE);
+            dbus_bus_add_match(app->dbus_conn_session, filter_string, &error);
+            if (dbus_error_is_set(&error)){
+                 fprintf(stderr,"dbus_bus_add_match failed: %s", error.message);
+                 dbus_error_free(&error);
+            }
+            g_free(filter_string);
+            /* add the callback */
+            dbus_connection_add_filter(app->dbus_conn_session,
+                                       get_omweather_signal_cb,
+                                       NULL, NULL);
+        }
 #if defined OS2009 && defined APPLICATION
         dbus_error_init (&error);
         dbus_bus_add_match(app->dbus_conn, MCE_MATCH_RULE, &error);
@@ -137,6 +153,8 @@ weather_deinitialize_dbus(void){
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+    gchar       *filter_string;
+    DBusError   error;
 #ifdef USE_CONIC
   if(app->connection){
       g_object_unref(app->connection);
@@ -148,13 +166,81 @@ weather_deinitialize_dbus(void){
          dbus_connection_remove_filter(app->dbus_conn,
              get_connection_status_signal_cb);
 #endif
+#if defined APPLICATION
          dbus_connection_close(app->dbus_conn);
          dbus_connection_unref(app->dbus_conn);
+#endif
+    }
+    if (app->dbus_conn_session){
+        filter_string =
+                g_strdup_printf("type='signal', interface='%s'", OMWEATHER_SIGNAL_INTERFACE);
+
+        dbus_error_init (&error);
+        dbus_bus_remove_match(app->dbus_conn_session, filter_string, &error);
+        if (!dbus_error_is_set(&error)){
+            dbus_connection_remove_filter(app->dbus_conn_session,
+                                          (DBusHandleMessageFunction)get_omweather_signal_cb, 
+                                          NULL);
+        }else{
+      
+            fprintf(stderr,"dbus_bus_add_match failed: %s", error.message);
+            dbus_error_free(&error);
+        }
+
+         g_free(filter_string);
     }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
 
+}
+/*******************************************************************************/
+void
+send_dbus_signal (const gchar *interface,
+                  const gchar *path,
+                  const gchar *member)
+{
+  gboolean       success;
+  
+  DBusMessage *message = dbus_message_new (DBUS_MESSAGE_TYPE_SIGNAL);
+  dbus_message_set_interface (message, interface);
+  dbus_message_set_path (message, path);
+  dbus_message_set_member (message, member);
+  success = dbus_connection_send (app->dbus_conn_session, message, NULL);
+  dbus_message_unref (message);
+  
+  fprintf (stderr, "%s '%s' message.\n",
+                                 success ? "Sent" : "Failed to send",
+                                 member);
+
+}
+
+/*******************************************************************************/
+DBusHandlerResult
+get_omweather_signal_cb(DBusConnection *conn, DBusMessage *msg, gpointer data){
+
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+/*
+#if defined OS2009 && defined APPLICATION
+    fprintf(stderr,"Application\n");
+#else 
+    fprintf(stderr,"Plugin\n");
+#endif
+*/
+    if (dbus_message_is_signal(msg, OMWEATHER_SIGNAL_INTERFACE, OMWEATHER_RELOAD_CONFIG)){
+        if(read_config(app->config)){
+                fprintf(stderr, "\nCan not read config file.\n");
+        }else{
+            redraw_home_window(FALSE);
+        }
+    }
+#ifndef APPLICATION
+    if (dbus_message_is_signal(msg, OMWEATHER_SIGNAL_INTERFACE, OMWEATHER_RELOAD_PLUGIN))
+        reload_omw_plugin();
+#endif
+    return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 /*******************************************************************************/
 #if !defined OS2008 && !defined OS2009 && !defined NONMAEMO
